@@ -24,14 +24,17 @@ The regex generation and parsing are tested in `tests/unit/test_format.py`.
 # at the root of this project. © 2021 Clément Haëck
 
 import re
-from typing import Any, Tuple, Union
+from typing import Any, Union
 
 
 def autoprop(*props):
-    """Generate properties for class."""
+    """Generate properties for class.
+
+    Properties all link to `cls.params` dictionnary.
+    """
     def factory_get(name):
         def getter(self):
-            return self.params[name]
+            return self.params.get(name, None)
         return getter
 
     def factory_set(name):
@@ -68,6 +71,7 @@ class Format:
 
     def __init__(self, fmt: str):
         self.fmt = fmt
+        self.params = {}
         self.parse_params(fmt)
         self.set_defaults()
 
@@ -155,25 +159,27 @@ class Format:
     def generate_expression_e(self) -> str:
         rgx = r'\d'
         rgx += self.get_right_point()
-        rgx += r'{}[+-]\d+?\d'.format(self.type)
+        rgx += r'{}[+-]\d+'.format(self.type)
         return self.insert_in_alignement(rgx)
 
     def insert_in_alignement(self, rgx: str) -> str:
-        align, loc = self.get_align()
+        fill_rgx = ''
+        if self.width > 0:
+            fill_rgx += '{}*'.format(re.escape(self.fill))
         out_rgx = ''
 
-        if loc in ['left', 'center']:
-            out_rgx += align
+        if self.align in '>^':
+            out_rgx += fill_rgx
 
         out_rgx += self.get_sign()
 
-        if loc == 'middle':
-            out_rgx += align
+        if self.align == '=':
+            out_rgx += fill_rgx
 
         out_rgx += rgx
 
-        if loc in ['right', 'center']:
-            out_rgx += align
+        if self.align in '<^':
+            out_rgx += fill_rgx
 
         return out_rgx
 
@@ -189,21 +195,6 @@ class Format:
             raise KeyError("Sign not in {+- }")
         return rgx
 
-    def get_align(self) -> Tuple[str, str]:
-        """Get alignment with fill regex and its location."""
-        rgx = ''
-        if self.width > 0:
-            rgx += '{}*'.format(re.escape(self.fill))
-
-        loc = {
-            '=': 'middle',
-            '>': 'left',
-            '<': 'right',
-            '^': 'center'
-        }[self.align]
-
-        return rgx, loc
-
     def get_left_point(self) -> str:
         """Get regex for numbers left of decimal point."""
         if self.grouping is not None:
@@ -228,7 +219,7 @@ class Format:
         """Parse float from formatted string."""
         return float(self.remove_special(s))
 
-    def remove_special(self, s: str) -> int:
+    def remove_special(self, s: str) -> str:
         """Remove special characters.
 
         Remove characters that throw off int() and float() parsing.
